==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/shells/generic/iggwidgetkeytrackball.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
// A widget that provides control to change a direction
//

#ifndef IGGWIDGETKEYTRACKBALL_H
#define IGGWIDGETKEYTRACKBALL_H


#include "iggwidgetkeyhandler.h"
#include "iggrenderwindowobserver.h"


class iObjectKey;

class ibgWidgetTrackBallSubject;


class iggWidgetKeyTrackBall : public iggWidgetKeyHandlerBase, public iggRenderWindowObserver
{

public:

    iggWidgetKeyTrackBall(const iObjectKey &dirkey, bool followCamera, int rm, iggFrame *parent, int index = -1, const iObjectKey *indkey = 0);
	virtual ~iggWidgetKeyTrackBall();

	inline void SetDirection(float x[3]) { this->SetDirection(x[0],x[1],x[2]); }
	virtual void SetDirection(float x, float y, float z);
	virtual void SetAngles(float elevation, float azimuth);

protected:

	virtual bool UpdateWidgetBody();
	virtual void OnBool1Body(bool final);
	virtual void OnRenderWindowModified();

	ibgWidgetTrackBallSubject *mSubject;
	bool mIsVectorKey;
};

#endif // IGGWIDGETKEYTRACKBALL_H

==> ifrit_3.3.2.orig.tar.gz: ifrit-3.3.2/shells/generic/iggwidgetkeytrackball.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
// A widget that provides control to change a direction
//

#ifndef IGGWIDGETKEYTRACKBALL_H
#define IGGWIDGETKEYTRACKBALL_H


#include "iggwidgetkeyhandler.h"
#include "iggrenderwindowobserver.h"


class iObjectKey;

class ibgWidgetTrackBallSubject;


class iggWidgetKeyTrackBall : public iggWidgetKeyHandlerBase, public iggRenderWindowObserver
{

public:

    iggWidgetKeyTrackBall(const iObjectKey &dirkey, bool followCamera, int rm, iggFrame *parent, int index = -1, const iObjectKey *indkey = 0);
	virtual ~iggWidgetKeyTrackBall();

	inline void SetDirection(float x[3]) { this->SetDirection(x[0],x[1],x[2]); }
	virtual void SetDirection(float x, float y, float z);
	virtual void SetAngles(float elevation, float azimuth);

protected:

	virtual void UpdateWidgetBody();
	virtual void OnBool1Body(bool final);
	virtual void OnRenderWindowModified();

	ibgWidgetTrackBallSubject *mSubject;
	bool mIsVectorKey;
};

#endif // IGGWIDGETKEYTRACKBALL_H
